import { CoreMessage, CoreTool as CT, LanguageModelV1 } from 'ai';
import { ZodSchema } from 'zod';
import { ToolsInput } from '../agent/types';
import { MastraBase } from '../base';
import { Run } from '../run/types';
import { CoreTool } from '../tools/types';
import { CustomModelConfig, GenerateReturn, GoogleGenerativeAISettings, ModelConfig, StructuredOutput } from './types';
export declare class LLM extends MastraBase {
    #private;
    constructor({ model }: {
        model: ModelConfig;
    });
    getModelType(): string;
    createOpenAICompatibleModel({ baseURL, apiKey, defaultModelName, modelName, fetch, }: {
        baseURL: string;
        apiKey: string;
        defaultModelName: string;
        modelName?: string;
        fetch?: typeof globalThis.fetch;
    }): LanguageModelV1;
    createModelDef({ model, }: {
        model: {
            type: string;
            name?: string;
            toolChoice?: 'auto' | 'required';
            baseURL?: string;
            fetch?: typeof globalThis.fetch;
            apiKey?: string;
        };
    }): LanguageModelV1;
    getParams({ tools, resultTool, model, }: {
        tools: Record<string, CoreTool>;
        resultTool?: {
            description: string;
            parameters: ZodSchema;
        };
        model: ({
            type: string;
            name?: string;
            toolChoice?: 'auto' | 'required';
            baseURL?: string;
            apiKey?: string;
            fetch?: typeof globalThis.fetch;
        } & GoogleGenerativeAISettings) | CustomModelConfig;
    }): Promise<{
        toolsConverted: Record<string, CT>;
        modelDef: LanguageModelV1;
        answerTool: {};
        toolChoice: "auto" | "required";
    }>;
    convertTools(tools?: ToolsInput): Record<string, CoreTool>;
    private isBaseOutputType;
    private baseOutputTypeSchema;
    private createOutputSchema;
    generate<S extends boolean = false, Z extends ZodSchema | undefined = undefined>(messages: string | string[] | CoreMessage[], { schema, stream, maxSteps, onFinish, onStepFinish, tools, convertedTools, runId, }?: {
        runId?: string;
        stream?: S;
        schema?: Z;
        onFinish?: (result: string) => Promise<void> | void;
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
        tools?: ToolsInput;
        convertedTools?: Record<string, CoreTool>;
    }): Promise<GenerateReturn<S, Z>>;
    __text({ messages, onStepFinish, maxSteps, tools, runId, convertedTools, }: {
        tools?: ToolsInput;
        convertedTools?: Record<string, CoreTool>;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
    } & Run): Promise<import("ai").GenerateTextResult<{}, never>>;
    __textObject({ messages, onStepFinish, maxSteps, tools, convertedTools, structuredOutput, runId, }: {
        structuredOutput: StructuredOutput | ZodSchema;
        tools?: ToolsInput;
        convertedTools?: Record<string, CoreTool>;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
    } & Run): Promise<import("ai").GenerateObjectResult<any>>;
    __stream({ messages, onStepFinish, onFinish, maxSteps, tools, runId, convertedTools, }: {
        tools?: ToolsInput;
        convertedTools?: Record<string, CoreTool>;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        onFinish?: (result: string) => Promise<void> | void;
        maxSteps?: number;
    } & Run): Promise<import("ai").StreamTextResult<{}>>;
    __streamObject({ messages, onStepFinish, onFinish, maxSteps, tools, convertedTools, structuredOutput, runId, }: {
        structuredOutput: StructuredOutput | ZodSchema;
        tools?: ToolsInput;
        convertedTools?: Record<string, CoreTool>;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        onFinish?: (result: string) => Promise<void> | void;
        maxSteps?: number;
    } & Run): Promise<import("ai").StreamObjectResult<any, any, never>>;
}
