import { z } from 'zod';
import { Agent } from '../agent';
import { MastraEngine } from '../engine';
import { LLM } from '../llm';
import { ModelConfig } from '../llm/types';
import { BaseLogger } from '../logger';
import { MastraMemory } from '../memory';
import { Run } from '../run/types';
import { SyncAction } from '../sync';
import { OtelConfig, Telemetry } from '../telemetry';
import { MastraVector } from '../vector';
import { Workflow } from '../workflows';
import { StripUndefined } from './types';
export declare class Mastra<TSyncs extends Record<string, SyncAction<any, any, any, any>> = Record<string, SyncAction<any, any, any, any>>, TAgents extends Record<string, Agent<any>> = Record<string, Agent<any>>, TWorkflows extends Record<string, Workflow> = Record<string, Workflow>, TLogger extends BaseLogger = BaseLogger> {
    private vectors?;
    private agents;
    private logger;
    private syncs;
    private workflows;
    private telemetry?;
    engine?: MastraEngine;
    memory?: MastraMemory;
    constructor(config?: {
        memory?: MastraMemory;
        syncs?: TSyncs;
        agents?: TAgents;
        engine?: MastraEngine;
        vectors?: Record<string, MastraVector>;
        logger?: TLogger | false;
        workflows?: TWorkflows;
        telemetry?: OtelConfig;
    });
    LLM(modelConfig: ModelConfig): LLM;
    sync<K extends keyof TSyncs>(key: K, params: TSyncs[K] extends SyncAction<any, infer TSchemaIn, any, any> ? TSchemaIn extends z.ZodSchema ? z.infer<TSchemaIn> : never : never, runId?: Run['runId']): Promise<StripUndefined<TSyncs[K]['outputSchema']>['_input']>;
    getAgent<TAgentName extends keyof TAgents>(name: TAgentName): TAgents[TAgentName];
    getAgents(): {
        name: string;
        instructions: string;
        modelProvider: string;
        modelName: string;
    }[];
    getWorkflow<TWorkflowId extends keyof TWorkflows>(id: TWorkflowId): TWorkflows[TWorkflowId];
    setLogger({ logger }: {
        logger: TLogger;
    }): void;
    getLogger(): TLogger;
    getTelemetry(): Telemetry | undefined;
    getLogsByRunId(runId: string): Promise<import("..").BaseLogMessage[]>;
}
