import { Telemetry } from '../telemetry';
export interface QueryResult {
    id: string;
    score: number;
    metadata?: Record<string, any>;
}
export interface IndexStats {
    dimension: number;
    count: number;
    metric?: 'cosine' | 'euclidean' | 'dotproduct';
}
export declare abstract class MastraVector {
    #private;
    /**
     * Set the telemetry on the vector
     * @param telemetry
     */
    __setTelemetry(telemetry: Telemetry): void;
    /**
     * Get the telemetry on the vector
     * @returns telemetry
     */
    __getTelemetry(): Telemetry | undefined;
    abstract upsert(indexName: string, vectors: number[][], metadata?: Record<string, any>[], ids?: string[]): Promise<string[]>;
    abstract createIndex(indexName: string, dimension: number, metric?: 'cosine' | 'euclidean' | 'dotproduct'): Promise<void>;
    abstract query(indexName: string, queryVector: number[], topK?: number, filter?: Record<string, any>): Promise<QueryResult[]>;
    abstract listIndexes(): Promise<string[]>;
    abstract describeIndex(indexName: string): Promise<IndexStats>;
    abstract deleteIndex(indexName: string): Promise<void>;
}
