import { z } from 'zod';
import { IAction, MastraPrimitives } from '../action';
import { MastraBase } from '../base';
import { Step } from './step';
import { RetryConfig, StepConfig, StepGraph, StepResult } from './types';
export declare class Workflow<TSteps extends Step<any, any, any>[] = any, TTriggerSchema extends z.ZodType<any> = any> extends MastraBase {
    #private;
    name: string;
    /**
     * Creates a new Workflow instance
     * @param name - Identifier for the workflow (not necessarily unique)
     * @param logger - Optional logger instance
     */
    constructor({ name, triggerSchema, retryConfig, mastra, }: {
        name: string;
        triggerSchema?: TTriggerSchema;
        retryConfig?: RetryConfig;
        mastra?: MastraPrimitives;
    });
    /**
     * Initializes the XState machine for the workflow
     *
     * Registers the machine's types, actions, actors, initial context, entry actions, initial state, and states
     * @returns The initialized machine
     */
    private initializeMachine;
    step<TStep extends IAction<any, any, any, any>, CondStep extends IAction<any, any, any, any> | 'trigger', VarStep extends IAction<any, any, any, any> | 'trigger'>(step: TStep, config?: StepConfig<TStep, CondStep, VarStep>): this;
    then<TStep extends IAction<any, any, any, any>, CondStep extends IAction<any, any, any, any>, VarStep extends IAction<any, any, any, any>>(step: TStep, config?: StepConfig<TStep, CondStep, VarStep>): this;
    after<TStep extends IAction<any, any, any, any>>(step: TStep): Omit<typeof this, "then" | "after">;
    /**
     * Executes the workflow with the given trigger data
     * @param triggerData - Initial data to start the workflow with
     * @returns Promise resolving to workflow results or rejecting with error
     * @throws Error if trigger schema validation fails
     */
    execute({ triggerData, loadSnapshot, }?: {
        triggerData?: z.infer<TTriggerSchema>;
        loadSnapshot?: {
            runId: string;
        };
    }): Promise<{
        triggerData?: z.infer<TTriggerSchema>;
        results: Record<string, StepResult<any>>;
        runId: string;
    }>;
    /**
     * Rebuilds the machine with the current steps configuration and validates the workflow
     *
     * This is the last step of a workflow builder method chain
     * @throws Error if validation fails
     *
     * @returns this instance for method chaining
     */
    commit(): this;
    __registerPrimitives(p: MastraPrimitives): void;
    get stepGraph(): StepGraph;
}
